Struct whirlpools::state::TickArray
source · pub struct TickArray {
pub start_tick_index: i32,
pub ticks: [Tick; 88],
pub whirlpool: Pubkey,
}Expand description
Account: TickArray
Fields
start_tick_index: i32ticks: [Tick; 88]whirlpool: PubkeyTrait Implementations
sourceimpl AccountDeserialize for TickArray
impl AccountDeserialize for TickArray
sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
sourceimpl AccountSerialize for TickArray
impl AccountSerialize for TickArray
sourceimpl BorshDeserialize for TickArraywhere
i32: BorshDeserialize,
[Tick; 88]: BorshDeserialize,
Pubkey: BorshDeserialize,
impl BorshDeserialize for TickArraywhere i32: BorshDeserialize, [Tick; 88]: BorshDeserialize, Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl BorshSerialize for TickArraywhere
i32: BorshSerialize,
[Tick; 88]: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for TickArraywhere i32: BorshSerialize, [Tick; 88]: BorshSerialize, Pubkey: BorshSerialize,
sourceimpl Discriminator for TickArray
impl Discriminator for TickArray
const DISCRIMINATOR: [u8; 8] = _
fn discriminator() -> [u8; 8]
impl Copy for TickArray